/*
 * Copyright (c) 2015, Freescale Semiconductor, Inc.
 * Copyright 2016-2017 NXP
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of the copyright holder nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "fsl_debug_console.h"
#include "board.h"
#include "fsl_ftm.h"

#include "pin_mux.h"
#include "clock_config.h"
/*******************************************************************************
 * Definitions
 ******************************************************************************/
#define BOARD_FTM_BASEADDR FTM2

/* FTM channel used for input capture */
#define BOARD_FTM_INPUT_CAPTURE_CHANNEL kFTM_Chnl_0

/* Interrupt number and interrupt handler for the FTM base address used */
#define FTM_INTERRUPT_NUMBER FTM0_IRQn
#define FTM_INPUT_CAPTURE_HANDLER FTM0_IRQHandler

/* Interrupt to enable and flag to read */
#define FTM_CHANNEL_INTERRUPT_ENABLE kFTM_Chnl0InterruptEnable
#define FTM_CHANNEL_FLAG kFTM_Chnl0Flag

/*******************************************************************************
 * Prototypes
 ******************************************************************************/

/*******************************************************************************
 * Variables
 ******************************************************************************/
volatile bool ftmIsrFlag = false;

/*******************************************************************************
 * Code
 ******************************************************************************/
void FTM_INPUT_CAPTURE_HANDLER(void)
{
    if ((FTM_GetStatusFlags(BOARD_FTM_BASEADDR) & FTM_CHANNEL_FLAG) == FTM_CHANNEL_FLAG)
    {
        /* Clear interrupt flag.*/
        FTM_ClearStatusFlags(BOARD_FTM_BASEADDR, FTM_CHANNEL_FLAG);
    }
    ftmIsrFlag = true;
}
void delaynstep(int i)
{
	while(i--);
}
/*!
 * @brief Main function
 */
//static const clock_ip_name_t s_ftmClocks[] = FTM_CLOCKS;
int main(void)
{
    ftm_config_t ftmInfo;
    uint32_t captureVal;
    ftm_phase_params_t phaseA, phaseB;
    gpio_pin_config_t led_config = {kGPIO_DigitalOutput, 0};
    int i;
    /* Board pin, clock, debug console init */
    BOARD_InitPins();
    BOARD_BootClockRUN();
    BOARD_InitDebugConsole();
    GPIO_PinInit(GPIOC, 1, &led_config);
    GPIO_PinInit(GPIOC, 2, &led_config);
    /* Print a note to terminal */
    PRINTF("\r\nFTM input capture example\r\n");
    PRINTF("\r\nOnce the input signal is received the input capture value is printed\r\n");

    FTM_GetDefaultConfig(&ftmInfo);
    /* Initialize FTM module */
#if 0
    FTM_Init(BOARD_FTM_BASEADDR, &ftmInfo);
    FTM2->MOD=0xff;
    FTM2->CNTIN=0x7f;

    phaseA.enablePhaseFilter=0;
    phaseA.phaseFilterVal=0;
    phaseA.phasePolarity=kFTM_QuadPhaseNormal;
    phaseB.enablePhaseFilter=0;
    phaseB.phaseFilterVal=0;
    phaseB.phasePolarity=kFTM_QuadPhaseNormal;

    FTM_SetupQuadDecode(BOARD_FTM_BASEADDR,&phaseA,&phaseB, kFTM_QuadCountAndDir);

    FTM_StartTimer(BOARD_FTM_BASEADDR, kFTM_SystemClock);
#else
//    CLOCK_EnableClock(s_ftmClocks[FTM_GetInstance(BOARD_FTM_BASEADDR)]);
    SIM->SCGC6 |= 1<<26;
    FTM2->SC=0x00;
    FTM2->CONF |= FTM_CONF_BDMMODE(3);
    FTM2->MOD=20;
    FTM2->CNTIN=0;
    FTM2->CONTROLS[0].CnSC=0;
    FTM2->CONTROLS[1].CnSC=0;
    FTM2->QDCTRL|=0x01;
    FTM2->MODE|=0x05;
    FTM2->SC=0x48;
 //   FTM2->CNTIN=0;
#endif
    while (1)
    {
//    	getchar();
    	for(i=0;i<5;i++)
    	{
    		GPIO_TogglePinsOutput(GPIOC,1<<1);
    		delaynstep(100);
    		GPIO_TogglePinsOutput(GPIOC,1<<2);
    		delaynstep(100);

    	}
    	FTM2->SC &= ~(3<<3);    //disable FTM clock
    	FTM2->CNTIN = 3;
    	FTM2->CNT =6;
    	FTM2->SC |= 0x8;
    }
}
